from django.contrib import messages
from django.db.models.query_utils import Q
from django.shortcuts import render, get_object_or_404, redirect
from django.template.loader import render_to_string

from club.models import Club, MesBlogs
from lib.tools import confirmation
from lib.access_auth import access_restricted, none_if_anonymous
from portailuser.models import Ecole


@none_if_anonymous
def widget(request):
    """Widget pour les blogs favoris"""

    clubs = Club.objects.filter(ecole=request.ecole, mesblogs__utilisateur=request.user, blog_act=True)

    if not clubs:
        # On affiche juste le BDE dans le widget
        clubs = Club.objects.filter(ecole=Ecole.n7, ident="bde", blog_act=True)

    if not clubs:
        return None

    c = {
        "clubs": clubs,
    }

    return render_to_string("blogs_favoris/widget.html", c)


@access_restricted
def widget_settings(request):
    favoris = MesBlogs.objects.filter(utilisateur=request.user, ecole=request.ecole)

    search = request.POST.get("rech_club", "").strip()
    if search:
        results = Club.objects.filter(Q(ecole=request.ecole) & (Q(nom__icontains=search) | Q(ident__icontains=search)))
    else:
        results = None

    c = {
        "clubs": favoris,
        "resultats": results,
    }

    return render(request, "blogs_favoris/reglages.html", c)


@access_restricted
def ajout(request, club_id):
    club_ajout = Club.objects.filter(ecole=request.ecole, ident=club_id)

    if club_ajout.exists() and club_ajout[0].blog_act:
        MesBlogs.objects.get_or_create(club_fav=club_ajout[0], utilisateur=request.user, ecole=request.ecole)

    return redirect("blogs_favoris:widget_settings")


@access_restricted
def suppression(request, club_id):
    entry = get_object_or_404(
        MesBlogs,
        utilisateur=request.user,
        club_fav__ecole=request.ecole,
        club_fav__ident=club_id,
    )

    if request.method == "POST":
        if "conf_ok" in request.POST:
            entry.delete()
            messages.success(request, "Club favori supprimé avec succès.")

        return redirect("blogs_favoris:widget_settings")

    name = entry.club_fav.nom
    message = f"Voulez-vous vraiment supprimer le club « {name} » de " "vos favoris ?"
    boutons = (("conf_annul", "Annuler"), ("conf_ok", "Supprimer"))

    return confirmation(request, message, boutons)
